@@ -55,6 +55,9 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.3",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.4",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.5",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -124,6 +127,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 4.1",
     "Framework :: Django :: 4.2",
     "Framework :: Django :: 5.0",
+    "Framework :: Django :: 5.1",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -169,6 +173,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 15.0",
     "Framework :: Odoo :: 16.0",
     "Framework :: Odoo :: 17.0",
+    "Framework :: Odoo :: 18.0",
     "Framework :: OpenTelemetry",
     "Framework :: OpenTelemetry :: Distros",
     "Framework :: OpenTelemetry :: Exporters",
@@ -278,6 +283,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Artistic License",
     "License :: OSI Approved :: Attribution Assurance License",
     "License :: OSI Approved :: BSD License",
+    "License :: OSI Approved :: Blue Oak Model License (BlueOak-1.0.0)",
     "License :: OSI Approved :: Boost Software License 1.0 (BSL-1.0)",
     "License :: OSI Approved :: CEA CNRS Inria Logiciel Libre License, version 2.1 (CeCILL-2.1)",
     "License :: OSI Approved :: Common Development and Distribution License 1.0 (CDDL-1.0)",
@@ -350,6 +356,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Bulgarian",
     "Natural Language :: Cantonese",
     "Natural Language :: Catalan",
+    "Natural Language :: Catalan (Valencian)",
     "Natural Language :: Chinese (Simplified)",
     "Natural Language :: Chinese (Traditional)",
     "Natural Language :: Croatian",
@@ -361,6 +368,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Finnish",
     "Natural Language :: French",
     "Natural Language :: Galician",
+    "Natural Language :: Georgian",
     "Natural Language :: German",
     "Natural Language :: Greek",
     "Natural Language :: Hebrew",
@@ -514,6 +522,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Python :: 3.11",
     "Programming Language :: Python :: 3.12",
     "Programming Language :: Python :: 3.13",
+    "Programming Language :: Python :: 3.14",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
     "Programming Language :: Python :: Implementation :: IronPython",
